.. _utilipy-utils-string:

*******************************
String (`utilipy.utils.string`)
*******************************

.. currentmodule:: utilipy.utils.string


Reference/API
=============

.. automodapi:: utilipy.utils.string
